@@ -3,7 +3,9 @@
 # Copyright (C) Michigan State University, 2009-2013. It is licensed under
 # the three-clause BSD license; see doc/LICENSE.txt. Contact: ctb@msu.edu
 #
-import sys, os, shutil
+import sys
+import os
+import shutil
 from cStringIO import StringIO
 import traceback
 
@@ -11,14 +13,17 @@ import khmer_tst_utils as utils
 import khmer
 import screed
 
+
 def scriptpath(scriptfile):
     path = os.path.join(utils.thisdir, '..', 'scripts', scriptfile)
     path = os.path.abspath(path)
     return path
 
+
 def teardown():
     utils.cleanup()
 
+
 def runscript(scriptname, args, in_directory=None, fail_ok=False):
     """
     Run the given Python script, with the given args, in the given directory,
@@ -43,7 +48,7 @@ def runscript(scriptname, args, in_directory=None, fail_ok=False):
         try:
             print 'running:', scriptname, 'in:', in_directory
             print 'arguments', sysargs
-            execfile(scriptname, { '__name__' : '__main__' })
+            execfile(scriptname, {'__name__': '__main__'})
             status = 0
         except:
             traceback.print_exc(file=sys.stderr)
@@ -60,6 +65,7 @@ def runscript(scriptname, args, in_directory=None, fail_ok=False):
 
     return status, out, err
 
+
 def DEBUG_runscript(scriptname, args, in_directory=None, fail_ok=False):
     """
     Run the given Python script, with the given args, in the given directory,
@@ -81,7 +87,7 @@ def DEBUG_runscript(scriptname, args, in_directory=None, fail_ok=False):
 
         try:
             print 'running:', scriptname, 'in:', in_directory
-            execfile(scriptname, { '__name__' : '__main__' })
+            execfile(scriptname, {'__name__': '__main__'})
             status = 0
         except:
             traceback.print_exc(file=sys.stderr)
@@ -93,15 +99,16 @@ def DEBUG_runscript(scriptname, args, in_directory=None, fail_ok=False):
 
     if status != 0 and not fail_ok:
         raise Exception(status)
-    
+
     return status, "", ""
 
-####
+#
+
 
 def test_load_into_counting():
     script = scriptpath('load-into-counting.py')
     args = ['-x', '1e7', '-N', '2', '-k', '20']
-    
+
     outfile = utils.get_temp_filename('out.kh')
     infile = utils.get_test_data('test-abund-read-2.fa')
 
@@ -110,10 +117,11 @@ def test_load_into_counting():
     runscript(script, args)
     assert os.path.exists(outfile)
 
+
 def test_load_into_counting_fail():
     script = scriptpath('load-into-counting.py')
-    args = ['-x', '1e2', '-N', '2', '-k', '20'] # use small HT
-    
+    args = ['-x', '1e2', '-N', '2', '-k', '20']  # use small HT
+
     outfile = utils.get_temp_filename('out.kh')
     infile = utils.get_test_data('test-abund-read-2.fa')
 
@@ -125,13 +133,14 @@ def test_load_into_counting_fail():
     assert status == -1
     assert "ERROR:" in err
 
+
 def _make_counting(infilename, SIZE=1e7, N=2, K=20, BIGCOUNT=True):
     script = scriptpath('load-into-counting.py')
     args = ['-x', str(SIZE), '-N', str(N), '-k', str(K)]
 
     if not BIGCOUNT:
         args.append('-b')
-    
+
     outfile = utils.get_temp_filename('out.kh')
 
     args.extend([outfile, infilename])
@@ -141,6 +150,7 @@ def _make_counting(infilename, SIZE=1e7, N=2, K=20, BIGCOUNT=True):
 
     return outfile
 
+
 def test_filter_abund_1():
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -155,10 +165,11 @@ def test_filter_abund_1():
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
 
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 1, seqs
     assert 'GGTTGACGGGGCTCAGGG' in seqs
 
+
 def test_filter_abund_2():
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -173,11 +184,13 @@ def test_filter_abund_2():
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
 
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 2, seqs
     assert 'GGTTGACGGGGCTCAGGG' in seqs
 
 # make sure that FASTQ records are retained.
+
+
 def test_filter_abund_3_fq_retained():
     infile = utils.get_temp_filename('test.fq')
     in_dir = os.path.dirname(infile)
@@ -192,15 +205,16 @@ def test_filter_abund_3_fq_retained():
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
 
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 2, seqs
     assert 'GGTTGACGGGGCTCAGGG' in seqs
 
     # check for 'accuracy' string.
-    seqs = set([ r.accuracy for r in screed.open(outfile) ])
+    seqs = set([r.accuracy for r in screed.open(outfile)])
     assert len(seqs) == 2, seqs
     assert '##################' in seqs
 
+
 def test_filter_abund_1_singlefile():
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -214,11 +228,13 @@ def test_filter_abund_1_singlefile():
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
 
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 1, seqs
     assert 'GGTTGACGGGGCTCAGGG' in seqs
 
 # test that the -V option does not trim sequences that are low abundance
+
+
 def test_filter_abund_4_retain_low_abund():
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -233,11 +249,13 @@ def test_filter_abund_4_retain_low_abund():
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
 
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 2, seqs
     assert 'GGTTGACGGGGCTCAGGG' in seqs
 
 # test that the -V option *does* trim sequences that are low abundance
+
+
 def test_filter_abund_5_trim_high_abund():
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -252,13 +270,15 @@ def test_filter_abund_5_trim_high_abund():
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
 
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 2, seqs
 
     # trimmed sequence @ error
     assert 'GGTTGACGGGGCTCAGGGGGCGGCTGACTCCGAGAGACAGC' in seqs
 
 # test that -V/-Z setting - should not trip if -Z is set high enough.
+
+
 def test_filter_abund_6_trim_high_abund_Z():
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -273,13 +293,15 @@ def test_filter_abund_6_trim_high_abund_Z():
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
 
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 2, seqs
 
     # untrimmed seq.
-    badseq = 'GGTTGACGGGGCTCAGGGGGCGGCTGACTCCGAGAGACAGCgtgCCGCAGCTGTCGTCAGGGGATTTCCGGGCGG'
+    badseq = 'GGTTGACGGGGCTCAGGGGGCGGCTGACTCCGAGAGACAGCgtgCCGCAGCTGTCGTCAGGG' \
+             'GATTTCCGGGCGG'
     assert badseq in seqs       # should be there, untrimmed
 
+
 def test_filter_stoptags():
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -294,7 +316,7 @@ def test_filter_stoptags():
     kh.add_stop_tag('GTTGACGGGGCTCAGGGG')
     kh.save_stop_tags(stopfile)
     del kh
-    
+
     # finally, run filter-stoptags.
     script = scriptpath('filter-stoptags.py')
     args = ['-k', str(K), stopfile, infile, infile]
@@ -306,12 +328,13 @@ def test_filter_stoptags():
 
     # it should contain only one unique sequence, because we've trimmed
     # off everything after the beginning of the only long sequence in there.
-    seqs = set([ r.sequence for r in screed.open(outfile) ])
+    seqs = set([r.sequence for r in screed.open(outfile)])
     assert len(seqs) == 1, seqs
     assert 'GGTTGACGGGGCTCAGGG' in seqs, seqs
 
+
 def test_normalize_by_median():
-    CUTOFF='1'
+    CUTOFF = '1'
 
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -325,12 +348,13 @@ def test_normalize_by_median():
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
 
-    seqs = [ r.sequence for r in screed.open(outfile) ]
+    seqs = [r.sequence for r in screed.open(outfile)]
     assert len(seqs) == 1, seqs
     assert seqs[0].startswith('GGTTGACGGGGCTCAGGGGG'), seqs
 
+
 def test_normalize_by_median_2():
-    CUTOFF='2'
+    CUTOFF = '2'
 
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -344,13 +368,14 @@ def test_normalize_by_median_2():
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
 
-    seqs = [ r.sequence for r in screed.open(outfile) ]
+    seqs = [r.sequence for r in screed.open(outfile)]
     assert len(seqs) == 2, seqs
     assert seqs[0].startswith('GGTTGACGGGGCTCAGGGGG'), seqs
     assert seqs[1] == 'GGTTGACGGGGCTCAGGG', seqs
 
+
 def test_normalize_by_median_paired():
-    CUTOFF='1'
+    CUTOFF = '1'
 
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -364,40 +389,43 @@ def test_normalize_by_median_paired():
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
 
-    seqs = [ r.sequence for r in screed.open(outfile) ]
+    seqs = [r.sequence for r in screed.open(outfile)]
     assert len(seqs) == 2, seqs
     assert seqs[0].startswith('GGTTGACGGGGCTCAGGGGG'), seqs
     assert seqs[1].startswith('GGTTGACGGGGCTCAGGG'), seqs
 
+
 def test_normalize_by_median_impaired():
-    CUTOFF='1'
+    CUTOFF = '1'
 
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
-    
+
     shutil.copyfile(utils.get_test_data('test-abund-read-impaired.fa'), infile)
 
     script = scriptpath('normalize-by-median.py')
     args = ['-C', CUTOFF, '-p', '-k', '17', infile]
     runscript(script, args, in_dir, fail_ok=True)
 
+
 def test_normalize_by_median_force():
-    CUTOFF='1'
-    
+    CUTOFF = '1'
+
     corrupt_infile = utils.get_temp_filename('test-corrupt.fq')
     good_infile = utils.get_temp_filename('test-good.fq',
-                                        tempdir=os.path.dirname(corrupt_infile))
-    
+                                          tempdir=os.path.dirname(
+                                              corrupt_infile))
+
     in_dir = os.path.dirname(good_infile)
-    
+
     shutil.copyfile(utils.get_test_data('test-error-reads.fq'), corrupt_infile)
     shutil.copyfile(utils.get_test_data('test-fastq-reads.fq'), good_infile)
-    
+
     script = scriptpath('normalize-by-median.py')
     args = ['-f', '-C', CUTOFF, '-k', '17', corrupt_infile, good_infile]
-    
+
     (status, out, err) = runscript(script, args, in_dir)
-    
+
     test_ht = khmer.load_counting_hash(corrupt_infile + '.ht.failed')
     test_good_read = 'CAGGCGCCCACCACCGTGCCCTCCAACCTGATGGT'
     test_good_read2 = 'TAGTATCATCAAGGTTCAAGATGTTAATGAATAACAATTGCGCAGCAA'
@@ -407,22 +435,23 @@ def test_normalize_by_median_force():
     assert '*** Skipping' in err
     assert '** IOErrors' in err
 
+
 def test_normalize_by_median_dumpfrequency():
-    CUTOFF='1'
-    
+    CUTOFF = '1'
+
     infiles = [utils.get_temp_filename('test-0.fq')]
     in_dir = os.path.dirname(infiles[0])
-    for x in range(1,5):
+    for x in range(1, 5):
         infiles.append(utils.get_temp_filename('test-{x}.fq'.format(x=x),
-                                                tempdir=in_dir))
-    
+                                               tempdir=in_dir))
+
     for infile in infiles:
         shutil.copyfile(utils.get_test_data('test-fastq-reads.fq'), infile)
-    
+
     script = scriptpath('normalize-by-median.py')
     args = ['-d', '2', '-C', CUTOFF, '-k', '17']
     args.extend(infiles)
-    
+
     (status, out, err) = runscript(script, args, in_dir)
 
     test_ht = khmer.load_counting_hash(os.path.join(in_dir, 'backup.ht'))
@@ -430,13 +459,14 @@ def test_normalize_by_median_dumpfrequency():
     test_good_read2 = 'TAGTATCATCAAGGTTCAAGATGTTAATGAATAACAATTGCGCAGCAA'
     assert test_ht.count(test_good_read[:17]) > 0
     assert test_ht.count(test_good_read2[:17]) > 0
-    
+
     assert os.path.exists(os.path.join(in_dir, 'backup.ht'))
     assert out.count('Backup: Saving') == 2
     assert 'Nothing' in out
 
+
 def test_normalize_by_median_empty():
-    CUTOFF='1'
+    CUTOFF = '1'
 
     infile = utils.get_temp_filename('test.fa')
     in_dir = os.path.dirname(infile)
@@ -450,10 +480,10 @@ def test_normalize_by_median_empty():
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
 
+
 def test_count_median():
     infile = utils.get_temp_filename('test.fa')
     outfile = infile + '.counts'
-    in_dir = os.path.dirname(infile)
 
     shutil.copyfile(utils.get_test_data('test-abund-read-2.fa'), infile)
     counting_ht = _make_counting(infile, K=8)
@@ -464,13 +494,14 @@ def test_count_median():
 
     assert os.path.exists(outfile), outfile
 
-    data = [ x.strip() for x in open(outfile) ]
+    data = [x.strip() for x in open(outfile)]
     data = set(data)
     assert len(data) == 2, data
     assert 'seq 1001 1001.0 0.0 18' in data
     assert '895:1:37:17593:9954/1 1 103.803741455 303.702941895 114' in data
 
-####
+#
+
 
 def test_load_graph():
     script = scriptpath('load-graph.py')
@@ -499,6 +530,7 @@ def test_load_graph():
     x = ht.subset_count_partitions(subset)
     assert x == (1, 0), x
 
+
 def test_load_graph_no_tags():
     script = scriptpath('load-graph.py')
     args = ['-x', '1e7', '-N', '2', '-k', '20', '-n']
@@ -516,14 +548,15 @@ def test_load_graph_no_tags():
     tagset_file = outfile + '.tagset'
     assert not os.path.exists(tagset_file), tagset_file
 
-    ht = khmer.load_hashbits(ht_file)
+    assert khmer.load_hashbits(ht_file)
 
     # can't think of a good way to make sure this worked, beyond just
     # loading the ht file...
 
+
 def test_load_graph_fail():
     script = scriptpath('load-graph.py')
-    args = ['-x', '1e3', '-N', '2', '-k', '20'] # use small HT
+    args = ['-x', '1e3', '-N', '2', '-k', '20']  # use small HT
 
     outfile = utils.get_temp_filename('out')
     infile = utils.get_test_data('random-20-a.fa')
@@ -534,6 +567,7 @@ def test_load_graph_fail():
     assert status == -1
     assert "ERROR:" in err
 
+
 def _make_graph(infilename, SIZE=1e7, N=2, K=20,
                 do_partition=False,
                 annotate_partitions=False,
@@ -580,10 +614,11 @@ def _make_graph(infilename, SIZE=1e7, N=2, K=20,
 
     return outfile
 
+
 def _DEBUG_make_graph(infilename, SIZE=1e7, N=2, K=20,
-                do_partition=False,
-                annotate_partitions=False,
-                stop_big_traverse=False):
+                      do_partition=False,
+                      annotate_partitions=False,
+                      stop_big_traverse=False):
     script = scriptpath('load-graph.py')
     args = ['-x', str(SIZE), '-N', str(N), '-k', str(K)]
 
@@ -601,14 +636,14 @@ def _DEBUG_make_graph(infilename, SIZE=1e7, N=2, K=20,
     assert os.path.exists(tagset_file), tagset_file
 
     if do_partition:
-	print ">>>> DEBUG: Partitioning <<<"
+        print ">>>> DEBUG: Partitioning <<<"
         script = scriptpath('partition-graph.py')
         args = [outfile]
         if stop_big_traverse:
             args.insert(0, '--no-big-traverse')
         DEBUG_runscript(script, args)
 
-	print ">>>> DEBUG: Merging Partitions <<<"
+        print ">>>> DEBUG: Merging Partitions <<<"
         script = scriptpath('merge-partitions.py')
         args = [outfile, '-k', str(K)]
         DEBUG_runscript(script, args)
@@ -617,7 +652,7 @@ def _DEBUG_make_graph(infilename, SIZE=1e7, N=2, K=20,
         assert os.path.exists(final_pmap_file)
 
         if annotate_partitions:
-	    print ">>>> DEBUG: Annotating Partitions <<<"
+            print ">>>> DEBUG: Annotating Partitions <<<"
             script = scriptpath('annotate-partitions.py')
             args = ["-k", str(K), outfile, infilename]
 
@@ -629,9 +664,9 @@ def _DEBUG_make_graph(infilename, SIZE=1e7, N=2, K=20,
 
     return outfile
 
+
 def test_partition_graph_1():
     graphbase = _make_graph(utils.get_test_data('random-20-a.fa'))
-    in_dir = os.path.dirname(graphbase)
 
     script = scriptpath('partition-graph.py')
     args = [graphbase]
@@ -641,7 +676,7 @@ def test_partition_graph_1():
     script = scriptpath('merge-partitions.py')
     args = [graphbase, '-k', str(20)]
     runscript(script, args)
-    
+
     final_pmap_file = graphbase + '.pmap.merged'
     assert os.path.exists(final_pmap_file)
 
@@ -651,10 +686,10 @@ def test_partition_graph_1():
     x = ht.count_partitions()
     assert x == (1, 0)          # should be exactly one partition.
 
+
 def test_partition_graph_nojoin_k21():
     # test with K=21
     graphbase = _make_graph(utils.get_test_data('random-20-a.fa'), K=21)
-    in_dir = os.path.dirname(graphbase)
 
     script = scriptpath('partition-graph.py')
     args = [graphbase]
@@ -674,10 +709,10 @@ def test_partition_graph_nojoin_k21():
     x = ht.count_partitions()
     assert x == (99, 0)          # should be 99 partitions at K=21
 
+
 def test_partition_graph_nojoin_stoptags():
     # test with stoptags
     graphbase = _make_graph(utils.get_test_data('random-20-a.fa'))
-    in_dir = os.path.dirname(graphbase)
 
     # add in some stop tags
     ht = khmer.load_hashbits(graphbase + '.ht')
@@ -705,10 +740,10 @@ def test_partition_graph_nojoin_stoptags():
     x = ht.count_partitions()
     assert x == (2, 0)          # should be 2 partitions
 
+
 def test_partition_graph_big_traverse():
     graphbase = _make_graph(utils.get_test_data('biglump-random-20-a.fa'),
                             do_partition=True, stop_big_traverse=False)
-    in_dir = os.path.dirname(graphbase)
 
     final_pmap_file = graphbase + '.pmap.merged'
     assert os.path.exists(final_pmap_file)
@@ -719,11 +754,11 @@ def test_partition_graph_big_traverse():
     x = ht.count_partitions()
     assert x == (1, 0)          # should be exactly one partition.
 
+
 def test_partition_graph_no_big_traverse():
     # do NOT exhaustively traverse
     graphbase = _make_graph(utils.get_test_data('biglump-random-20-a.fa'),
                             do_partition=True, stop_big_traverse=True)
-    in_dir = os.path.dirname(graphbase)
 
     final_pmap_file = graphbase + '.pmap.merged'
     assert os.path.exists(final_pmap_file)
@@ -734,6 +769,7 @@ def test_partition_graph_no_big_traverse():
     x = ht.count_partitions()
     assert x == (4, 0), x       # should be four partitions, broken at knot.
 
+
 def test_annotate_partitions():
     seqfile = utils.get_test_data('random-20-a.fa')
     graphbase = _make_graph(seqfile, do_partition=True)
@@ -749,11 +785,12 @@ def test_annotate_partitions():
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
-    parts = [ r.name.split('\t')[1] for r in screed.open(partfile) ]
+    parts = [r.name.split('\t')[1] for r in screed.open(partfile)]
     parts = set(parts)
     assert '2' in parts
     assert len(parts) == 1
 
+
 def test_annotate_partitions_2():
     # test with K=21 (no joining of sequences)
     seqfile = utils.get_test_data('random-20-a.fa')
@@ -771,14 +808,16 @@ def test_annotate_partitions_2():
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
-    parts = [ r.name.split('\t')[1] for r in screed.open(partfile) ]
+    parts = [r.name.split('\t')[1] for r in screed.open(partfile)]
     parts = set(parts)
     print parts
     assert len(parts) == 99, len(parts)
 
+
 def test_extract_partitions():
     seqfile = utils.get_test_data('random-20-a.fa')
-    graphbase = _make_graph(seqfile, do_partition=True, annotate_partitions=True)
+    graphbase = _make_graph(
+        seqfile, do_partition=True, annotate_partitions=True)
     in_dir = os.path.dirname(graphbase)
 
     # get the final part file
@@ -787,7 +826,7 @@ def test_extract_partitions():
     # ok, now run extract-partitions.
     script = scriptpath('extract-partitions.py')
     args = ['extracted', partfile]
-    
+
     runscript(script, args, in_dir)
 
     distfile = os.path.join(in_dir, 'extracted.dist')
@@ -798,11 +837,12 @@ def test_extract_partitions():
     dist = open(distfile).readline()
     assert dist.strip() == '99 1 1 99'
 
-    parts = [ r.name.split('\t')[1] for r in screed.open(partfile) ]
+    parts = [r.name.split('\t')[1] for r in screed.open(partfile)]
     assert len(parts) == 99, len(parts)
     parts = set(parts)
     assert len(parts) == 1, len(parts)
 
+
 def test_abundance_dist():
     infile = utils.get_temp_filename('test.fa')
     outfile = utils.get_temp_filename('test.dist')
@@ -822,6 +862,7 @@ def test_abundance_dist():
     line = fp.next().strip()
     assert line == '1001 2 98 1.0', line
 
+
 def test_abundance_dist_nobigcount():
     infile = utils.get_temp_filename('test.fa')
     outfile = utils.get_temp_filename('test.dist')
@@ -841,6 +882,7 @@ def test_abundance_dist_nobigcount():
     line = fp.next().strip()
     assert line == '255 2 98 1.0', line
 
+
 def test_abundance_dist_single():
     infile = utils.get_temp_filename('test.fa')
     outfile = utils.get_temp_filename('test.dist')
@@ -858,6 +900,7 @@ def test_abundance_dist_single():
     line = fp.next().strip()
     assert line == '1001 2 98 1.0', line
 
+
 def test_abundance_dist_single_nobigcount():
     infile = utils.get_temp_filename('test.fa')
     outfile = utils.get_temp_filename('test.dist')
@@ -875,6 +918,7 @@ def test_abundance_dist_single_nobigcount():
     line = fp.next().strip()
     assert line == '255 2 98 1.0', line
 
+
 def test_do_partition():
     seqfile = utils.get_test_data('random-20-a.fa')
     graphbase = utils.get_temp_filename('out')
@@ -887,11 +931,12 @@ def test_do_partition():
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
-    parts = [ r.name.split('\t')[1] for r in screed.open(partfile) ]
+    parts = [r.name.split('\t')[1] for r in screed.open(partfile)]
     parts = set(parts)
     assert '2' in parts
     assert len(parts) == 1
 
+
 def test_do_partition_2():
     # test with K=21 (no joining of sequences)
     seqfile = utils.get_test_data('random-20-a.fa')
@@ -905,12 +950,13 @@ def test_do_partition_2():
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
-    parts = [ r.name.split('\t')[1] for r in screed.open(partfile) ]
+    parts = [r.name.split('\t')[1] for r in screed.open(partfile)]
     parts = set(parts)
 
     assert len(parts) == 99, len(parts)
 
-####
+#
+
 
 def test_interleave_reads_1_fq():
     # test input files
@@ -933,6 +979,7 @@ def test_interleave_reads_1_fq():
 
     assert r == q, (r, q)
 
+
 def test_interleave_reads_2_fa():
     # test input files
     infile1 = utils.get_test_data('paired.fa.1')
@@ -956,6 +1003,7 @@ def test_interleave_reads_2_fa():
         assert r.sequence == q.sequence
     assert n > 0
 
+
 def test_extract_paired_reads_1_fa():
     # test input file
     infile = utils.get_test_data('paired-mixed.fa')
@@ -972,7 +1020,7 @@ def test_extract_paired_reads_1_fa():
     args = [infile]
 
     runscript(script, args, in_dir)
-    
+
     assert os.path.exists(outfile1), outfile1
     assert os.path.exists(outfile2), outfile2
 
@@ -990,6 +1038,7 @@ def test_extract_paired_reads_1_fa():
         assert r.sequence == q.sequence
     assert n > 0
 
+
 def test_extract_paired_reads_2_fq():
     # test input file
     infile = utils.get_test_data('paired-mixed.fq')
@@ -1026,6 +1075,7 @@ def test_extract_paired_reads_2_fq():
         assert r.accuracy == q.accuracy
     assert n > 0
 
+
 def test_split_paired_reads_1_fa():
     # test input file
     infile = utils.get_test_data('paired.fa')
@@ -1060,6 +1110,7 @@ def test_split_paired_reads_1_fa():
         assert r.sequence == q.sequence
     assert n > 0
 
+
 def test_split_paired_reads_2_fq():
     # test input file
     infile = utils.get_test_data('paired.fq')
@@ -1095,3 +1146,26 @@ def test_split_paired_reads_2_fq():
         assert r.sequence == q.sequence
         assert r.accuracy == q.accuracy
     assert n > 0
+
+
+def test_sample_reads_randomly():
+    infile = utils.get_temp_filename('test.fq')
+    in_dir = os.path.dirname(infile)
+
+    shutil.copyfile(utils.get_test_data('test-fastq-reads.fq'), infile)
+
+    script = scriptpath('sample-reads-randomly.py')
+    # fix random number seed for reproducibility
+    args = ['-N', '10', '-R', '1']
+    args.append('test.fq')
+    runscript(script, args, in_dir)
+
+    outfile = infile + '.subset'
+    assert os.path.exists(outfile), outfile
+
+    seqs = set([r.name for r in screed.open(outfile)])
+    assert seqs == set(['895:1:1:1326:7273', '895:1:1:1373:4848',
+                        '895:1:1:1264:15854', '895:1:1:1338:15407',
+                        '895:1:1:1327:15301', '895:1:1:1265:2265',
+                        '895:1:1:1327:13028', '895:1:1:1368:4434',
+                        '895:1:1:1335:19932', '895:1:1:1340:19387'])
